<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>MX Tools</source>
        <translation type="unfinished">MX Araçları</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>About this application</source>
        <translation type="unfinished">Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>About...</source>
        <translation type="unfinished">Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Close application</source>
        <translation type="unfinished">Uygulamayı kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <source>Close</source>
        <translation type="unfinished">Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Manual</source>
        <translation type="unfinished">El ile</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="unfinished">Bu MX uygulamaları önemli görevlerde zamandan ve emekten tasarruf sağlar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Hide individual tools from the menu</source>
        <translation type="unfinished">Bireysel araçları menüde gösterme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>search</source>
        <translation type="unfinished">Ara</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>About MX Tools</source>
        <translation type="unfinished">MX Araçları Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>Version: </source>
        <translation type="unfinished">Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Configuration Tools for MX Linux</source>
        <translation type="unfinished">MX Linux için Yapılandırma Araçları</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>License</source>
        <translation type="unfinished">Ruhsat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Changelog</source>
        <translation type="unfinished">Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>Cancel</source>
        <translation type="unfinished">İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Kapat</translation>
    </message>
</context>
<context>
    <name>mxtools</name>
    <message>
        <source>MX Tools</source>
        <translation type="vanished">MX Araçları</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">Uygulama hakkında</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">Hakkında...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Close application</source>
        <translation type="vanished">Uygulamayı kapat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Kapat</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="vanished">El ile</translation>
    </message>
    <message>
        <source>These MX applications save time and effort with important tasks.</source>
        <translation type="vanished">Bu MX uygulamaları önemli görevlerde zamandan ve emekten tasarruf sağlar.</translation>
    </message>
    <message>
        <source>Hide individual tools from the menu</source>
        <translation type="vanished">Bireysel araçları menüde gösterme</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">Ara</translation>
    </message>
    <message>
        <source>About MX Tools</source>
        <translation type="vanished">MX Araçları Hakkında</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Sürüm</translation>
    </message>
    <message>
        <source>Configuration Tools for MX Linux</source>
        <translation type="vanished">MX Linux için Yapılandırma Araçları</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Ruhsat</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Değişim günlüğü</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">İptal</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Kapat</translation>
    </message>
</context>
</TS>
